@@ -25,9 +25,10 @@ typedef struct
 {
     XfcePanelPlugin *plugin;
 
-    /* panel widgets */
-    GtkWidget       *menu; 
+    /* panel widgets */ 
     GtkWidget       *item;
+    GtkWidget       *buttonbox;
+    GtkWidget       *ebox;
 
     /* indicator settings */
 }
